==> ejc-settlementmanage-api-3.0.0-20221206.022020-127-sources.jar: com/ejianc/business/settlementmanage/hystrix/CostManageHystrix.java <==
package com.ejianc.business.settlementmanage.hystrix;

import com.ejianc.business.settlementmanage.api.ICostManageApi;
import com.ejianc.business.settlementmanage.vo.CostManageVO;
import com.ejianc.business.settlementmanage.vo.LaborCostRequestVO;
import com.ejianc.business.settlementmanage.vo.LaborCostVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

@Component
public class CostManageHystrix implements ICostManageApi {
    @Override
    public CommonResponse<BigDecimal> queryCostaccountPartmaterial(Long projectId, String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
    @Override
    public CommonResponse<BigDecimal> queryCostaccountMechanical(Long projectId,String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
    @Override
    public CommonResponse<BigDecimal> queryProjectreportSettlement(Long contractId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<Map<String,LaborCostVO>> queryLabor(LaborCostRequestVO laborCostRequestVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<CostManageVO>> queryDesignSettlement(Long contractId) {
        throw new BusinessException("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<CostManageVO>> queryConsultotherfinal(Long contractId) {
        throw new BusinessException("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<LaborCostVO>> queryStatementAll(String projectId, String contractType, String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
}

==> ejc-settlementmanage-api-3.0.0-20230113.025707-167-sources.jar: com/ejianc/business/settlementmanage/hystrix/CostManageHystrix.java <==
package com.ejianc.business.settlementmanage.hystrix;

import com.ejianc.business.settlementmanage.api.ICostManageApi;
import com.ejianc.business.settlementmanage.vo.CostManageVO;
import com.ejianc.business.settlementmanage.vo.LaborCostRequestVO;
import com.ejianc.business.settlementmanage.vo.LaborCostVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

@Component
public class CostManageHystrix implements ICostManageApi {
    @Override
    public CommonResponse<BigDecimal> queryCostaccountPartmaterial(Long projectId, String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
    @Override
    public CommonResponse<BigDecimal> queryCostaccountMechanical(Long projectId,String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
    @Override
    public CommonResponse<BigDecimal> queryProjectreportSettlement(Long contractId) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<Map<String,LaborCostVO>> queryLabor(LaborCostRequestVO laborCostRequestVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> queryDesignSettlement(Long projectId, String monthStr) {
        throw new BusinessException("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> queryConsultotherfinal(Long projectId, String monthStr) {
        throw new BusinessException("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<LaborCostVO>> queryStatementAll(String projectId, String contractType, String time) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
}
